summaryrefslogtreecommitdiff
path: root/include/llvm/System/Path.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/System/Path.h')
-rw-r--r--include/llvm/System/Path.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/System/Path.h b/include/llvm/System/Path.h
index 97876a3f81f..537a5af5a39 100644
--- a/include/llvm/System/Path.h
+++ b/include/llvm/System/Path.h
@@ -112,15 +112,15 @@ namespace sys {
/// @brief Construct a path to the system library directory
static void GetSystemLibraryPaths(std::vector<sys::Path>& Paths);
/// Construct a vector of sys::Path that contains the "standard" bytecode
/// library paths suitable for linking into an llvm program. This function
/// *must* return the value of LLVM_LIB_SEARCH_PATH as well as the value
/// of LLVM_LIBDIR. It also must provide the System library paths as
/// returned by GetSystemLibraryPaths.
/// @see GetSystemLibraryPaths
/// @brief Construct a list of directories in which bytecode could be
/// found.
- static void GetBytecodeLibraryPaths(std::vector<sys::Path>& Paths);
+ static void GetBitcodeLibraryPaths(std::vector<sys::Path>& Paths);
/// Find the path to a library using its short name. Use the system
/// dependent library paths to locate the library.
@@ -112,15 +112,15 @@ namespace sys {
/// @brief Construct a path to the system library directory
static void GetSystemLibraryPaths(std::vector<sys::Path>& Paths);
- /// Construct a vector of sys::Path that contains the "standard" bytecode
+ /// Construct a vector of sys::Path that contains the "standard" bitcode
/// library paths suitable for linking into an llvm program. This function
/// *must* return the value of LLVM_LIB_SEARCH_PATH as well as the value
@@ -112,15 +112,15 @@ namespace sys {
/// returned by GetSystemLibraryPaths.
/// @see GetSystemLibraryPaths
- /// @brief Construct a list of directories in which bytecode could be
+ /// @brief Construct a list of directories in which bitcode could be
/// found.